@@ -18,8 +18,16 @@
 #include <QScrollArea>
 #include <QVBoxLayout>
 #include <QPalette>
+#include <QProcess>
+#include <QTimer>
+#include <QTextEdit>
 
-
+void maemoBanner(QString string)
+{
+    QProcess *myProcess = new QProcess;
+    QString program = "dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"" + string + "\"";
+    myProcess->execute(program);
+}
 
 
 MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
@@ -47,15 +55,20 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     w->setStationsListConnection(true);
     w->loadCurrentIndex();
 
+    readLastFreq();
+
     setWindowTitle("QRadio");
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	
 	
+    if (showCustomBackground)
+    {
+        QPalette p = palette();
+        QPixmap pixmap1("/opt/qradio/background.png");
+        p.setBrush(QPalette::Background,  pixmap1);
+        setPalette(p);
+    }
 
-    QPalette p = palette();
-    QPixmap pixmap1("/opt/qradio/background.png");
-    p.setBrush(QPalette::Background,  pixmap1);
-            setPalette(p);
 }
 
 MainWindow::~MainWindow()
@@ -108,6 +121,12 @@ void MainWindow::createActions()
     speakersAction = new QAction("Speakers", this);
     speakersAction->setCheckable(true);
     connect(speakersAction, SIGNAL(triggered()), SLOT(speakersActionTriggered()));
+
+    autoScanAction = new QAction("AutoScan", this);
+    connect(autoScanAction, SIGNAL(triggered()), SLOT(autoScanActionTriggered()));
+
+    helpAction = new QAction("Help", this);
+    connect(helpAction, SIGNAL(triggered()), SLOT(helpActionTriggered()));
 }
 
 void MainWindow::readSetsName()
@@ -136,6 +155,8 @@ void MainWindow::createMenu()
     menu->addAction(manualAction);
     menu->addAction(stationsListAction);
     menu->addAction(speakersAction);
+    menu->addAction(autoScanAction);
+    menu->addAction(helpAction);
     menu->addAction(settingsAction);
     menu->addAction(aboutAction);
     menu->addAction(aboutQtAction);
@@ -220,23 +241,6 @@ void MainWindow::manualActionTriggered()
     if (ok) w->setFreq(manualFreq*1000000);
 }
 
-/*void MainWindow::renameSetsActionTriggered()
-{
-    bool ok1;
-    bool ok2;
-    bool ok3;
-    QString set1NameTemp = QInputDialog::getText(this, "Sets Rename", "Insert Set1 Name:", QLineEdit::Normal, set1Name, &ok1 , 0);
-    QString set2NameTemp = QInputDialog::getText(this, "Sets Rename", "Insert Set2 Name:", QLineEdit::Normal, set2Name, &ok2 , 0);
-    QString set3NameTemp = QInputDialog::getText(this, "Sets Rename", "Insert Set3 Name:", QLineEdit::Normal, set3Name, &ok3 , 0);
-    if (ok1) set1Name = set1NameTemp;
-    if (ok2) set2Name = set2NameTemp;
-    if (ok3) set3Name = set3NameTemp;
-    saveSetsName();
-    set1Action->setText(set1Name);
-    set2Action->setText(set2Name);
-    set3Action->setText(set3Name);
-}*/
-
 void MainWindow::stationsListActionTriggered()
 {
     QStringList stats;
@@ -268,6 +272,7 @@ void MainWindow::settingsActionTriggered()
 
     connect(s, SIGNAL(quickAccessChanged(bool)), SLOT(quickAccessChanged(bool)));
     connect(s, SIGNAL(monoModeChanged(bool)), SLOT(changeMonoMode(bool)));
+    connect(s, SIGNAL(showBackgroundClicked(bool)), SLOT(setBackgroundVar(bool)));
 
     connect(s, SIGNAL(fontChanged(QString,int,int)), SLOT(changeFont(QString,int,int)));
     s->show();
@@ -297,7 +302,7 @@ void MainWindow::manageStationsActionTriggered()
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                tr("<h2>QRadio 0.3.5</h2>"
+                tr("<h2>QRadio 0.3.6</h2>"
                    "<p>"
                    "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 
@@ -314,6 +319,7 @@ void MainWindow::readSettings()
     QSettings settings("Maemo", "qradio");
     monoMode=settings.value("monoMode", false).toBool();
     quickAccess=settings.value("quickAccess", false).toBool();
+    showCustomBackground=settings.value("showCustomBackground", false).toBool();
     currentFont=settings.value("currentFont", "Digital-7").toString();
     currentFreqFontSize=settings.value("currentFreqFontSize", 170).toInt();
     currentLabelsFontSize = settings.value("currentLabelsFontSize", 25).toInt();
@@ -429,6 +435,7 @@ void MainWindow::saveSettings()
     settings.setValue("currentFont", currentFont);
     settings.setValue("currentFreqFontSize", currentFreqFontSize);
     settings.setValue("currentLabelsFontSize", currentLabelsFontSize);
+    settings.setValue("showCustomBackground", showCustomBackground);
 }
 
 void MainWindow::changeMonoMode(bool mode)
@@ -482,3 +489,82 @@ void MainWindow::listEdited(QStringList stationList)
    w->setStationsListConnection(true);
 
 }
+
+void MainWindow::setBackgroundVar(bool showBack)
+{
+    maemoBanner("Restart App to reload Background");
+    showCustomBackground = showBack;
+}
+
+void MainWindow::autoScanActionTriggered()
+{
+    int tempFreq = w->getFreq();
+    if (tempFreq<87500000) tempFreq = 87500000;
+
+
+    do
+    {
+        w->setFreq(tempFreq);
+        if (w->getSignalStrenght()>0)
+        {
+            this->addStationTriggered();
+            maemoBanner("Station found ("+ QString::number(tempFreq/1000) +")");
+            //sleep(1);
+        }
+        tempFreq+=100000;
+
+    }
+
+    while (tempFreq<108000000);
+    maemoBanner("AutoScan completed");
+}
+
+void MainWindow::helpActionTriggered()
+{
+    QMainWindow *helpWindow = new QMainWindow(this);
+    helpWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
+    helpWindow->setWindowFlags(helpWindow->windowFlags() | Qt::Window);
+    helpWindow->setWindowTitle("QRadio");
+
+    QTextEdit *textEdit = new QTextEdit;
+    textEdit->setFixedHeight(900);
+    textEdit->adjustSize();
+    textEdit->setReadOnly(true);
+
+    QScrollArea *scrollArea = new QScrollArea;
+
+    QString text("Thanks for using this App. \n"
+                 "\n"
+                 "To change frequency, tap once on the blue arrows to change freq by 100kHz or hold the arrows down to seek up and down for a station. \n"
+                 "The QuickAccess buttons are hidden by default, to show use the Settings Window. Tapping once on a QuickAccess button will change the freq to the shown value, holding it down will save the current freq to the selected button. \n"
+                 "The small radio button on the bottom left will show the saved stations for the current set, the button in the bottom right will toggle the fullscreen mode and the white arrows will navigate throught the saved stations. \n"
+                 "\n"
+                 "This app gives you 3 sets of saved stations. To switch set just tap on it in the App menu. Set Names can be changed in settings window.\n"
+                 "AddStation: tapping on it will save the current freq into the current set.\n"
+                 "Manage Stations: tap on it to show the stations management window, where saved stations of the current set can be moved or deleted by holding down the relative icon. Tapping on the freq name button will change the current freq to that value.\n"
+                 "Manual: tap on it to insert manually the desired frequency.\n"
+                 "Stations List: same behavior of the small bottom left button.\n"
+                 "Speakers: tap on it to toggle speakers output. To learn more about it check the Maemo.org topic about QRadio"
+                 "AutoScan: tapping on it will start the autoscan. Starting from the current freq, all stations will be saved into the current set.\n");
+    QVBoxLayout *layout = new QVBoxLayout;
+    layout->addWidget(textEdit);
+    textEdit->setText(text);
+
+    QWidget *widget = new QWidget;
+    widget->setLayout(layout);
+
+    scrollArea->setWidget(widget);
+    scrollArea->setWidgetResizable(true);
+    helpWindow->setCentralWidget(scrollArea);
+
+    helpWindow->show();
+
+
+}
+
+void MainWindow::readLastFreq()
+{
+    QSettings settings("Maemo", "qradio");
+    int lastFreq = settings.value("LastFreq", 87500000).toInt();
+    w->setFreq(lastFreq);
+}
